@@ -1,6 +1,6 @@
 #' Relabel columns to match the selection table format 
 #' 
-#' \code{ relabel_colms} relabels columns to match the selection table format (as in the R package \code{\link{warbleR}})
+#' \code{ relabel_colms} relabels columns to match the selection table format (as in the R package \href{https://cran.r-project.org/package=warbleR}{warbleR})
 #' @usage  relabel_colms(X, extra.cols.name = NULL, extra.cols.new.name = NULL, 
 #' khz.to.hz = FALSE, hz.to.khz = FALSE, waveform = FALSE)
 #' @param X Data frame imported from Raven.
@@ -9,14 +9,14 @@
 #' @param extra.cols.new.name Character vector with the new names for the additional columns to be relabeled. 
 #' Default is \code{NULL}. 'extra.cols.name' must also be provided.
 #' @param khz.to.hz Logical. Controls if frequency variables ('top.freq' and 'bottom.freq') should be converted from kHz 
-#' (the unit used by other bioacoustic analysis R packages like \code{\link{warbleR}}) to Hz (the unit used by Raven). 
+#' (the unit used by other bioacoustic analysis R packages like \href{https://cran.r-project.org/package=warbleR}{warbleR}) to Hz (the unit used by Raven). 
 #' Default is \code{FALSE}.
 #' @param hz.to.khz Logical. Controls if frequency variables ('top.freq' and 'bottom.freq') should be converted from Hz 
-#' (the unit used by other bioacoustic analysis R packages like Raven) to kHz (the unit used by \code{\link{warbleR}}). 
+#' (the unit used by other bioacoustic analysis R packages like Raven) to kHz (the unit used by \href{https://cran.r-project.org/package=warbleR}{warbleR}). 
 #' Default is \code{FALSE}. Ignored if 'kHz.to.hz' is \code{TRUE}.
 #' @param waveform Logical to control if 'waveform' related data should be included (this data is typically duplicated in 'spectrogram' data).  Default is \code{FALSE} (not to include it).
 #' @return The function returns the input data frame with new column names for time and frequency 'coordinates' and sound files and selections.
-#' @details This function relabels columns to match the selection table format to match then ones used by other bioacoustic analysis R packages like \code{\link{warbleR}}. 
+#' @details This function relabels columns to match the selection table format to match then ones used by other bioacoustic analysis R packages like \href{https://cran.r-project.org/package=warbleR}{warbleR}. 
 #' @seealso \code{\link{imp_raven}}; \code{\link{exp_raven}} 
 #' @export
 #' @name  relabel_colms
@@ -60,14 +60,14 @@
    op.dig <- options(digits = 6)
    
   #if X is not a data frame
-  if (!class(X) == "data.frame") stop("X is not a data frame")
+  if (!methods::is(X, "data.frame")) stop2("X is not a data frame")
   
   # if not extra.cols.new.name and extra.cols.name are provided
-  if (any(!is.null(extra.cols.name) & is.null(extra.cols.new.name), is.null(extra.cols.name) & !is.null(extra.cols.new.name))) stop("if either 'extra.cols.name' or 'extra.cols.new.name' are provided the other must be provided as well")
+  if (any(!is.null(extra.cols.name) & is.null(extra.cols.new.name), is.null(extra.cols.name) & !is.null(extra.cols.new.name))) stop2("if either 'extra.cols.name' or 'extra.cols.new.name' are provided the other must be provided as well")
 
   # if not the same length
   if (length(extra.cols.new.name) != length(extra.cols.name)) 
-    stop("'extra.cols.name' and 'extra.cols.new.name' must have the same length")
+    stop2("'extra.cols.name' and 'extra.cols.new.name' must have the same length")
     
   # remove waveform rows
   if (!waveform & any(names(X) == "View"))
